==> haskell-hspec-discover-2.9.6-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-discover.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hspec-discover
version:              2.9.6
visibility:           public
id:                   hspec-discover-2.9.6-E69x69tyQpf2iV4W2wiFXP
key:                  hspec-discover-2.9.6-E69x69tyQpf2iV4W2wiFXP
license:              MIT
copyright:            (c) 2012-2021 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
stability:            experimental
homepage:             http://hspec.github.io/
synopsis:             Automatically discover and run Hspec tests
description:
    Automatically discover and run Hspec tests

    <http://hspec.github.io/hspec-discover.html>

category:             Testing
abi:                  402999d55be438e0233ea5d24b2b8f5b
exposed-modules:
    Test.Hspec.Discover.Config Test.Hspec.Discover.Run
    Test.Hspec.Discover.Sort

hidden-modules:       Paths_hspec_discover
import-dirs:          /usr/lib/ghc-9.0.2/site-local/hspec-discover-2.9.6
library-dirs:         /usr/lib/ghc-9.0.2/site-local/hspec-discover-2.9.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-discover
hs-libraries:         HShspec-discover-2.9.6-E69x69tyQpf2iV4W2wiFXP
depends:              base-4.15.1.0 directory-1.3.6.2 filepath-1.4.2.1
haddock-interfaces:
    /usr/share/doc/haskell-hspec-discover/html/hspec-discover.haddock

haddock-html:         /usr/share/doc/haskell-hspec-discover/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-discover-2.9.6-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-discover.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hspec-discover
version:              2.9.6
visibility:           public
id:                   hspec-discover-2.9.6-BuJ9pegO4giF0ZHdoIC0hj
key:                  hspec-discover-2.9.6-BuJ9pegO4giF0ZHdoIC0hj
license:              MIT
copyright:            (c) 2012-2021 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
stability:            experimental
homepage:             http://hspec.github.io/
synopsis:             Automatically discover and run Hspec tests
description:
    Automatically discover and run Hspec tests

    <http://hspec.github.io/hspec-discover.html>

category:             Testing
abi:                  ebfcf76fc899f14dcd716f06f3d23980
exposed-modules:
    Test.Hspec.Discover.Config Test.Hspec.Discover.Run
    Test.Hspec.Discover.Sort

hidden-modules:       Paths_hspec_discover
import-dirs:          /usr/lib/ghc-9.0.2/site-local/hspec-discover-2.9.6
library-dirs:         /usr/lib/ghc-9.0.2/site-local/hspec-discover-2.9.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-discover
hs-libraries:         HShspec-discover-2.9.6-BuJ9pegO4giF0ZHdoIC0hj
depends:              base-4.15.1.0 directory-1.3.6.2 filepath-1.4.2.1
haddock-interfaces:
    /usr/share/doc/haskell-hspec-discover/html/hspec-discover.haddock

haddock-html:         /usr/share/doc/haskell-hspec-discover/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
